@@ -33,8 +33,13 @@
 #include "mhw_mi.h"
 #include "mos_utilities.h"
 #include "media_perf_profiler.h"
+#include "renderhal.h"
 #define BIT( n )                            ( 1 << (n) )
 
+#ifdef min
+#undef min
+#endif
+
 //!
 //! \brief    BltState constructor
 //! \details  Initialize the BltState members.
@@ -134,7 +139,6 @@ MOS_STATUS BltState::CopyMainSurface(
 
     BLT_CHK_NULL_RETURN(src);
     BLT_CHK_NULL_RETURN(dst);
-    MOS_TraceEventExt(EVENT_MEDIA_COPY, EVENT_TYPE_START, nullptr, 0, nullptr, 0);
 
     MOS_ZeroMemory(&bltStateParam, sizeof(BLT_STATE_PARAM));
     bltStateParam.bCopyMainSurface = true;
@@ -143,7 +147,6 @@ MOS_STATUS BltState::CopyMainSurface(
 
     BLT_CHK_STATUS_RETURN(SubmitCMD(&bltStateParam));
 
-    MOS_TraceEventExt(EVENT_MEDIA_COPY, EVENT_TYPE_END, nullptr, 0, nullptr, 0);
     return MOS_STATUS_SUCCESS;
 
 }
@@ -157,6 +160,8 @@ MOS_STATUS BltState::CopyMainSurface(
 //!           [in] Pointer to input surface
 //! \param    outputSurface
 //!           [in] Pointer to output surface
+//! \param    planeIndex
+//!           [in] Pointer to YUV(RGB) plane index
 //! \return   MOS_STATUS
 //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
 //!
@@ -169,9 +174,7 @@ MOS_STATUS BltState::SetupBltCopyParam(
     BLT_CHK_NULL_RETURN(pMhwBltParams);
     BLT_CHK_NULL_RETURN(inputSurface);
     BLT_CHK_NULL_RETURN(outputSurface);
-    BLT_CHK_NULL_RETURN(outputSurface->pGmmResInfo);
 
-    uint32_t          BytesPerTexel = 1;
     MOS_SURFACE       ResDetails;
     MOS_ZeroMemory(&ResDetails, sizeof(MOS_SURFACE));
     MOS_ZeroMemory(pMhwBltParams, sizeof(MHW_FAST_COPY_BLT_PARAM));
@@ -183,7 +186,7 @@ MOS_STATUS BltState::SetupBltCopyParam(
     uint32_t inputPitch  = ResDetails.dwPitch;
 
     if (inputSurface->TileType != MOS_TILE_LINEAR)
-    { 
+    { ///for tiled surfaces, pitch is expressed in DWORDs
         pMhwBltParams->dwSrcPitch = ResDetails.dwPitch / 4;
     }
     else
@@ -203,7 +206,7 @@ MOS_STATUS BltState::SetupBltCopyParam(
     uint32_t outputPitch  = ResDetails.dwPitch;
 
     if (outputSurface->TileType != MOS_TILE_LINEAR)
-    {
+    {// /for tiled surfaces, pitch is expressed in DWORDs
         pMhwBltParams->dwDstPitch = ResDetails.dwPitch/4;
     }
     else
@@ -214,29 +217,45 @@ MOS_STATUS BltState::SetupBltCopyParam(
     pMhwBltParams->dwDstLeft   = ResDetails.RenderOffset.YUV.Y.XOffset;
 
     int planeNum = GetPlaneNum(ResDetails.Format);
-    pMhwBltParams->dwDstRight = std::min(inputWidth, outputWidth);
+    pMhwBltParams->dwDstBottom = std::min(inputHeight, outputHeight);
 
-    if (outputSurface->pGmmResInfo->GetResourceType() != RESOURCE_BUFFER)
+    // some upper layer has overwrite the format, so need get orignal BitsPerBlock
+    BLT_CHK_NULL_RETURN(inputSurface->pGmmResInfo);
+    BLT_CHK_NULL_RETURN(outputSurface->pGmmResInfo);
+    uint32_t inputBitsPerPixel  = inputSurface->pGmmResInfo->GetBitsPerPixel();
+    uint32_t outputBitsPerPixel = outputSurface->pGmmResInfo->GetBitsPerPixel();
+    uint32_t BitsPerPixel       = 8;
+    if (inputSurface->TileType != MOS_TILE_LINEAR)
     {
-        BytesPerTexel = outputSurface->pGmmResInfo->GetBitsPerPixel() / 8;  // using Bytes.
-        if (ResDetails.Format == Format_P010 || ResDetails.Format == Format_P016)
-        {
-            BytesPerTexel = 2;
-        }
+        BitsPerPixel = inputBitsPerPixel;
     }
-
-    if (true == m_blokCopyon)
+    else if (outputSurface->TileType != MOS_TILE_LINEAR)
     {
-        pMhwBltParams->dwColorDepth = GetBlkCopyColorDepth(outputSurface->pGmmResInfo->GetResourceFormat(), BytesPerTexel);
+        BitsPerPixel = outputBitsPerPixel;
     }
     else
     {
-        pMhwBltParams->dwColorDepth = GetFastCopyColorDepth(outputSurface->pGmmResInfo->GetResourceFormat(), BytesPerTexel);
+        // both input and output are linear surfaces.
+        // upper layer overwrite the format from buffer to 2D surfaces. Then the BitsPerPixel may different.
+        BitsPerPixel = inputBitsPerPixel >= outputBitsPerPixel ? inputBitsPerPixel : outputBitsPerPixel;
     }
+    MCPY_NORMALMESSAGE("input BitsPerBlock %d, output BitsPerBlock %d, the vid mem BitsPerBlock %d",
+        inputBitsPerPixel,
+        outputBitsPerPixel,
+        BitsPerPixel);
 
-    if( 1 == planeNum )
+    if (true == m_blokCopyon)
+    {
+        pMhwBltParams->dwColorDepth = GetBlkCopyColorDepth(outputSurface->pGmmResInfo->GetResourceFormat(), BitsPerPixel);
+    }
+    else
+    {
+        pMhwBltParams->dwColorDepth = GetFastCopyColorDepth(outputSurface->pGmmResInfo->GetResourceFormat(), BitsPerPixel);
+    }
+    pMhwBltParams->dwPlaneIndex = planeIndex;
+    pMhwBltParams->dwPlaneNum   = planeNum;
+    if (SINGLE_PLANE == planeNum)
     {// handle as whole memory
-       pMhwBltParams->dwDstBottom = std::min(inputHeight, outputHeight);
        if (false == m_blokCopyon)
        {// fastcopy
            pMhwBltParams->dwDstRight   = std::min(inputPitch, outputPitch) / 4;  // Regard as 32 bit per pixel format, i.e. 4 byte per pixel.
@@ -244,17 +263,15 @@ MOS_STATUS BltState::SetupBltCopyParam(
        }
        else
        {
-           // Block copy
-           pMhwBltParams->dwDstRight = std::min(inputPitch, outputPitch) / 4;  // Regard as 32 bit per pixel format, i.e. 4 byte per pixel.
-           pMhwBltParams->dwColorDepth = 2;  //0:8bit 1:16bit 2:32bit
+           pMhwBltParams->dwDstRight  = std::min(inputWidth, outputWidth);
        }
     }
     else
     {
         int bytePerTexelScaling    = GetBytesPerTexelScaling(ResDetails.Format);
-        pMhwBltParams->dwDstBottom = std::min(inputHeight, outputHeight);
+        pMhwBltParams->dwDstRight  = std::min(inputWidth, outputWidth);
 
-        if (1 == planeIndex || 2 == planeIndex)
+        if (MCPY_PLANE_U == planeIndex || MCPY_PLANE_V == planeIndex)
         {
            pMhwBltParams->dwDstBottom = pMhwBltParams->dwDstBottom / bytePerTexelScaling;
            if (ResDetails.Format == Format_I420 || ResDetails.Format == Format_YV12)
@@ -311,6 +328,7 @@ MOS_STATUS BltState::SubmitCMD(
     // Initialize the command buffer struct
     MOS_ZeroMemory(&cmdBuffer, sizeof(MOS_COMMAND_BUFFER));
     BLT_CHK_STATUS_RETURN(m_osInterface->pfnGetCommandBuffer(m_osInterface, &cmdBuffer, 0));
+    BLT_CHK_STATUS_RETURN(SetPrologParamsforCmdbuffer(&cmdBuffer));
 
     // Add flush DW
     MHW_MI_FLUSH_DW_PARAMS FlushDwParams;
@@ -342,7 +360,7 @@ MOS_STATUS BltState::SubmitCMD(
             &fastCopyBltParam,
             pBltStateParam->pSrcSurface,
             pBltStateParam->pDstSurface,
-            0));
+            MCPY_PLANE_Y));
 
         MHW_MI_LOAD_REGISTER_IMM_PARAMS RegisterDwParams;
         MOS_ZeroMemory(&RegisterDwParams, sizeof(RegisterDwParams));
@@ -369,37 +387,32 @@ MOS_STATUS BltState::SubmitCMD(
             srcResDetails.YPlaneOffset.iSurfaceOffset,
             dstResDetails.YPlaneOffset.iSurfaceOffset));
 
-        if (planeNum >= 2)
+        if (planeNum == TWO_PLANES || planeNum == THREE_PLANES)
         {
             BLT_CHK_STATUS_RETURN(SetupBltCopyParam(
              &fastCopyBltParam,
              pBltStateParam->pSrcSurface,
              pBltStateParam->pDstSurface,
-             1));
+             MCPY_PLANE_U));
             BLT_CHK_STATUS_RETURN(m_bltInterface->AddBlockCopyBlt(
                  &cmdBuffer,
                  &fastCopyBltParam,
                  srcResDetails.UPlaneOffset.iSurfaceOffset,
                  dstResDetails.UPlaneOffset.iSurfaceOffset));
 
-              if (planeNum == 3)
+              if (planeNum == THREE_PLANES)
               {
                   BLT_CHK_STATUS_RETURN(SetupBltCopyParam(
                       &fastCopyBltParam,
                       pBltStateParam->pSrcSurface,
                       pBltStateParam->pDstSurface,
-                      2));
+                      MCPY_PLANE_V));
                   BLT_CHK_STATUS_RETURN(m_bltInterface->AddBlockCopyBlt(
                       &cmdBuffer,
                       &fastCopyBltParam,
                       srcResDetails.VPlaneOffset.iSurfaceOffset,
                       dstResDetails.VPlaneOffset.iSurfaceOffset));
               }
-              else if (planeNum > 3)
-              {
-                  MCPY_ASSERTMESSAGE("illegal usage");
-                  return MOS_STATUS_INVALID_PARAMETER;
-              }
          }
     }
 
@@ -418,49 +431,42 @@ MOS_STATUS BltState::SubmitCMD(
 
 uint32_t BltState::GetBlkCopyColorDepth(
     GMM_RESOURCE_FORMAT dstFormat,
-    uint32_t            BytesPerTexel)
+    uint32_t            BitsPerPixel)
 {
-    uint32_t bitsPerTexel = BytesPerTexel * BLT_BITS_PER_BYTE;
-
-    switch (bitsPerTexel)
+    if (dstFormat == GMM_FORMAT_YUY2_2x1 || dstFormat == GMM_FORMAT_Y216_TYPE || dstFormat == GMM_FORMAT_Y210)
+    {   // GMM_FORMAT_YUY2_2x1 32bpe 2x1 pixel blocks instead of 16bpp 1x1 block
+        // GMM_FORMAT_Y216_TYPE/Y210 64bpe pixel blocks instead of 32bpp block.
+         BitsPerPixel = BitsPerPixel / 2;
+    }
+    switch (BitsPerPixel)
     {
-     case 8:
-         return mhw_blt_state::XY_BLOCK_COPY_BLT_CMD::COLOR_DEPTH_8BITCOLOR;
-         break;
-     case 16:
+    case 16:
          switch (dstFormat)
          {
-           case GMM_FORMAT_B5G5R5A1_UNORM:
-               return mhw_blt_state::XY_BLOCK_COPY_BLT_CMD::COLOR_DEPTH_32BITCOLOR;
-               break;
-           default:
-               return mhw_blt_state::XY_BLOCK_COPY_BLT_CMD::COLOR_DEPTH_16BITCOLOR;;
-               break;
+         case GMM_FORMAT_B5G5R5A1_UNORM:
+              return mhw_blt_state::XY_BLOCK_COPY_BLT_CMD::COLOR_DEPTH_32BITCOLOR;
+         default:
+              return mhw_blt_state::XY_BLOCK_COPY_BLT_CMD::COLOR_DEPTH_16BITCOLOR;
          }
-         break;
-     case 64:
+    case 32:
+         return mhw_blt_state::XY_BLOCK_COPY_BLT_CMD::COLOR_DEPTH_32BITCOLOR;
+    case 64:
          return mhw_blt_state::XY_BLOCK_COPY_BLT_CMD::COLOR_DEPTH_64BITCOLOR;
-         break;
-     case 96:
-         return mhw_blt_state::XY_BLOCK_COPY_BLT_CMD::COLOR_DEPTH_32BITCOLOR;
-         break;
-     case 128:
+    case 96:
+         MCPY_ASSERTMESSAGE("96 BitPerPixel support limimated as Linear format %d", dstFormat);
+         return mhw_blt_state::XY_BLOCK_COPY_BLT_CMD::COLOR_DEPTH_96BITCOLOR_ONLYLINEARCASEISSUPPORTED;
+    case 128:
          return mhw_blt_state::XY_BLOCK_COPY_BLT_CMD::COLOR_DEPTH_128BITCOLOR;
-         break;
-     default:
-         return mhw_blt_state::XY_BLOCK_COPY_BLT_CMD::COLOR_DEPTH_32BITCOLOR;
-         break;
+    case 8:
+    default:
+         return mhw_blt_state::XY_BLOCK_COPY_BLT_CMD::COLOR_DEPTH_8BITCOLOR;
     }
-
- }
-
+}
 uint32_t BltState::GetFastCopyColorDepth(
      GMM_RESOURCE_FORMAT dstFormat,
-     uint32_t            BytesPerTexel)
+    uint32_t             BitsPerBlock)
  {
-     uint32_t bitsPerTexel = BytesPerTexel * BLT_BITS_PER_BYTE;
-
-     switch (bitsPerTexel)
+     switch (BitsPerBlock)
      {
      case 8:
          return mhw_blt_state::XY_FAST_COPY_BLT_CMD::COLOR_DEPTH_8BITCOLOR;
@@ -509,14 +515,14 @@ uint32_t BltState::GetFastCopyColorDepth(
 int BltState::GetPlaneNum(MOS_FORMAT format)
 {
 
-  int  planeNum = 1;
+  int planeNum = SINGLE_PLANE;
 
    switch (format)
    {
        case Format_NV12:
        case Format_P010:
        case Format_P016:
-            planeNum = 2;
+           planeNum = TWO_PLANES;
            break;
        case Format_YV12:
        case Format_I420:
@@ -527,11 +533,60 @@ int BltState::GetPlaneNum(MOS_FORMAT format)
        case Format_411P:
        case Format_422V:
        case Format_422H:
-            planeNum = 3;
+            planeNum = THREE_PLANES;
             break;
        default:
-            planeNum = 1;
+            planeNum = SINGLE_PLANE;
            break;
     }
    return planeNum;
+ }
+
+MOS_STATUS BltState::SetPrologParamsforCmdbuffer(PMOS_COMMAND_BUFFER cmdBuffer)
+ {
+   PMOS_INTERFACE                  pOsInterface;
+   MOS_STATUS                      eStatus = MOS_STATUS_SUCCESS;
+   uint32_t                        iRemaining;
+   RENDERHAL_GENERIC_PROLOG_PARAMS GenericPrologParams = {};
+   PMOS_RESOURCE                   gpuStatusBuffer     = nullptr;
+
+   //---------------------------------------------
+   BLT_CHK_NULL_RETURN(cmdBuffer);
+   BLT_CHK_NULL_RETURN(m_osInterface);
+   //---------------------------------------------
+
+   eStatus      = MOS_STATUS_SUCCESS;
+   pOsInterface = m_osInterface;
+
+   MOS_GPU_CONTEXT gpuContext = m_osInterface->pfnGetGpuContext(m_osInterface);
+
+#ifndef EMUL
+   if (pOsInterface->bEnableKmdMediaFrameTracking)
+   {
+           // Get GPU Status buffer
+           BLT_CHK_STATUS_RETURN(pOsInterface->pfnGetGpuStatusBufferResource(pOsInterface, gpuStatusBuffer));
+           BLT_CHK_NULL_RETURN(gpuStatusBuffer);
+           // Register the buffer
+           BLT_CHK_STATUS_RETURN(pOsInterface->pfnRegisterResource(pOsInterface, gpuStatusBuffer, true, true));
+
+           GenericPrologParams.bEnableMediaFrameTracking      = true;
+           GenericPrologParams.presMediaFrameTrackingSurface  = gpuStatusBuffer;
+           GenericPrologParams.dwMediaFrameTrackingTag        = pOsInterface->pfnGetGpuStatusTag(pOsInterface, pOsInterface->CurrentGpuContextOrdinal);
+           GenericPrologParams.dwMediaFrameTrackingAddrOffset = pOsInterface->pfnGetGpuStatusTagOffset(pOsInterface, pOsInterface->CurrentGpuContextOrdinal);
+
+           // Increment GPU Status Tag
+           pOsInterface->pfnIncrementGpuStatusTag(pOsInterface, pOsInterface->CurrentGpuContextOrdinal);
+   }
+#endif
+
+   if (GenericPrologParams.bEnableMediaFrameTracking)
+   {
+           BLT_CHK_NULL_RETURN(GenericPrologParams.presMediaFrameTrackingSurface);
+           cmdBuffer->Attributes.bEnableMediaFrameTracking      = GenericPrologParams.bEnableMediaFrameTracking;
+           cmdBuffer->Attributes.dwMediaFrameTrackingTag        = GenericPrologParams.dwMediaFrameTrackingTag;
+           cmdBuffer->Attributes.dwMediaFrameTrackingAddrOffset = GenericPrologParams.dwMediaFrameTrackingAddrOffset;
+           cmdBuffer->Attributes.resMediaFrameTrackingSurface   = GenericPrologParams.presMediaFrameTrackingSurface;
+   }
+
+   return eStatus;
  }
\ No newline at end of file
