@@ -32,6 +32,7 @@
 #include "mhw_vdbox_mfx_itf.h"
 #include "mhw_vdbox_huc_itf.h"
 #include "encode_mem_compression.h"
+#include "media_copy_wrapper.h"
 #include "codechal_debug.h"
 
 namespace encode
@@ -103,8 +104,10 @@ public:
                     CodechalHwInterfaceNext *hwInterface,
                     TrackedBuffer *trackedBuf,
                     RecycleResource *recycleBuf,
+                    MediaCopyWrapper *mediaCopyWrapper,
                     void *constSettings = nullptr) :
-                    EncodeBasicFeature(allocator, hwInterface, trackedBuf, recycleBuf) {m_constSettings = constSettings;}
+                    EncodeBasicFeature(allocator, hwInterface, trackedBuf, recycleBuf),
+                    m_mediaCopyWrapper(mediaCopyWrapper) { m_constSettings = constSettings; }
 
     virtual ~AvcBasicFeature();
 
@@ -117,7 +120,7 @@ public:
     bool IsAvcPSlice(uint8_t sliceType) const;
     bool IsAvcBSlice(uint8_t sliceType) const;
 
-    MHW_SETPAR_DECL_HDR(VDENC_PIPE_MODE_SELECT);
+    virtual MHW_SETPAR_DECL_HDR(VDENC_PIPE_MODE_SELECT);
 
     MHW_SETPAR_DECL_HDR(VDENC_SRC_SURFACE_STATE);
 
@@ -241,11 +244,12 @@ protected:
     MOS_STATUS SetSequenceStructs();
     MOS_STATUS SetPictureStructs();
     MOS_STATUS UpdateSeiParameters(EncoderParams* params);
-    void UpdateMinMaxQp();
+    virtual void UpdateMinMaxQp();
     int32_t GetMaxMBPS(uint8_t levelIdc);
     MOS_STATUS SetSliceStructs();
     void CheckResolutionChange();
     MOS_STATUS PackPictureHeader();
+    virtual bool InputSurfaceNeedsExtraCopy(const MOS_SURFACE &input);
 
     virtual MOS_STATUS UpdateTrackedBufferParameters() override;
     virtual MOS_STATUS GetTrackedBuffers() override;
@@ -292,6 +296,8 @@ protected:
     uint32_t              m_seiDataOffset  = false;    //!< Encode SEI data offset.
     uint8_t *             m_seiParamBuffer = nullptr;  //!< Encode SEI data buffer.
 
+    MediaCopyWrapper *m_mediaCopyWrapper = nullptr;
+
 MEDIA_CLASS_DEFINE_END(encode__AvcBasicFeature)
 };
 
