@@ -392,7 +392,7 @@ struct _MHW_PAR_T(VDENC_AVC_IMG_STATE)
     uint8_t  intraRefreshMbSizeMinusOne             = 0;
     uint8_t  intraRefreshEnableRollingIEnable       = 0;
     uint8_t  intraRefreshMode                       = 0;
-    uint8_t  qpAdjustmentForRollingI                = 0;
+    int8_t   qpAdjustmentForRollingI                = 0;
     uint8_t  roiQpAdjustmentForZone0                = 0;
     uint8_t  roiQpAdjustmentForZone1                = 0;
     uint8_t  roiQpAdjustmentForZone2                = 0;
@@ -410,6 +410,13 @@ struct _MHW_PAR_T(VDENC_AVC_IMG_STATE)
     uint8_t  pocNumberForFwdRef1                    = 0;
     uint8_t  pocNumberForFwdRef2                    = 0;
     uint8_t  pocNumberForBwdRef0                    = 0;
+    uint8_t  plAdaptFrameField                      = 0;
+    uint8_t  currFrmFldPic                          = 0;
+    uint8_t  curPicType                             = 0;
+    uint8_t  fwdRefIdx0FieldType                    = 0;
+    uint8_t  bwdRefIdx0FieldType                    = 0;
+    uint8_t  fwdRefIdx1FieldType                    = 0;
+    uint8_t  fwdRefIdx2FieldType                    = 0;
 
     __MHW_VDBOX_VDENC_WRAPPER(
         std::vector<std::function<MOS_STATUS(uint32_t *)>> extSettings);
@@ -567,7 +574,7 @@ struct _MHW_PAR_T(VDENC_CMD2)
     uint8_t  intraRefreshMbSizeMinus1         = 1;
     uint8_t  intraRefreshMode                 = 0;
     bool     intraRefresh                     = false;
-    int8_t   qpAdjustmentForRollingI          = 0;
+    uint8_t  qpAdjustmentForRollingI          = 0;
     uint8_t  qpForSegs[8]                     = {};
     bool     vp9DynamicSlice                  = false;
     uint8_t  qpPrimeYDc                       = 0;
